/*
 * @(#)src/classes/sov/java/net/NetUtil.java, net, as142 1.1
 * ===========================================================================
 * IBM Confidential
 * OCO Source Materials
 *
 * IBM SDK, Java(tm) 2 Technology Edition, v1.4.2
 * (C) Copyright IBM Corp. 2001, 2013.
 *
 * The source code for this program is not published or otherwise divested of
 * its trade secrets, irrespective of what has been deposited with the U.S.
 * Copyright office.
 * ===========================================================================
 */

/*
 * Copyright (c) 2013 Oracle and/or its affiliates. All rights reserved.
 * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/*
 * Change activity:
 *
 * Reason   Date   Origin   Description
 * ------   ----   ------   -------------------------------------------------- 
 * 197402   180513 jitendsi Integrating OSB : 8001318 (new file)
 *
 * ===========================================================================
 */ 

package java.net;

import java.security.AccessController;
import java.security.PrivilegedExceptionAction;

class NetUtil {

    // Value of jdk.net.revealLocalAddress
    private static boolean revealLocalAddress;
    private static String temprevealLocalAddress;

    // True if jdk.net.revealLocalAddress had been read
    private static volatile boolean propRevealLocalAddr;

    /*
     * Returns true if security check on localAddress is disabled
     */
    static boolean doRevealLocalAddress() {
        return propRevealLocalAddr ? revealLocalAddress
                                     : readRevealLocalAddr();

    }

    static InetAddress getLoopbackAddress() {
        InetAddress loopbackAddress = null;
        try{
            loopbackAddress = InetAddress.getByName(null);
        } catch (UnknownHostException x) {
            throw new AssertionError("This should never happen");
        }
        return loopbackAddress;
    }

    private static boolean readRevealLocalAddr() {
        SecurityManager sm = System.getSecurityManager();
        if (sm != null) {
            try {
                temprevealLocalAddress = (String)AccessController.doPrivileged(
                    new PrivilegedExceptionAction() {
                        public Object run() {
                            return System.getProperty(
                                "jdk.net.revealLocalAddress");
                        }
                    });
                if (temprevealLocalAddress != null) {
                    revealLocalAddress = temprevealLocalAddress.equalsIgnoreCase("true");
                } else {
                    revealLocalAddress = false;
                }

            } catch (Exception e) {
                //revealLocalAddress is false
            }
            propRevealLocalAddr = true;
        }
        /*
         * No security manager, or security check passed or
         * jdk.net.revealLocalAddress set to true
         */
        return revealLocalAddress;
    }

}

